# <center>Gabriel<center>

![Gabriel](assets/downloadaaaa.jpg "Gabriel")

Gabriel is a Discord RPC cli tool

# Usage

Config:
```bash
gab --config <config file>.json
```

For help:
```
gab --help
```
or
```
gab -h
```
# Example config file
```json
{
    "client_id": "CLIENT_ID",
    "details": "Details",
    "state": "State message",
    "lg_img": "image",
    "lg_text": "tooptip",
    "sm_img":"image",
    "sm_text": "tooptip"
}
```
# Installation
Through python:
```
pip install gabriel
```

Linux packages coming soon
